@@ -638,16 +638,16 @@ class NmrDataSet:
                 f.close()
                 nd2 = nd.NmrData()
                 for kk in nd2.__dict__.keys():
-                    if kk is not 'acq' and kk is not 'proc' and kk is not 'display' and kk is not 'apc':
+                    if kk != 'acq' and kk != 'proc' and kk != 'display' and kk != 'apc':
                         if hasattr(n, kk):
                             exec('nd2.' + kk + '=n.' + kk)
 
-                    elif kk is 'acq':
+                    elif kk == 'acq':
                         if hasattr(n, kk):
                             a = n.acq
                             aq = nd2.acq
                             for kkk in aq.__dict__.keys():
-                                if kkk is not 'regEx':
+                                if kkk != 'regEx':
                                     if hasattr(a, kkk):
                                         exec('aq.' + kkk + '=a.' + kkk)
 
@@ -664,12 +664,12 @@ class NmrDataSet:
                             nd2.acq = aq
 
 
-                    elif kk is 'proc':
+                    elif kk == 'proc':
                         if hasattr(n, kk):
                             p = n.proc
                             pc = nd2.proc
                             for kkk in pc.__dict__.keys():
-                                if kkk is not 'regEx':
+                                if kkk != 'regEx':
                                     if hasattr(p, kkk):
                                         exec('pc.' + kkk + '=p.' + kkk)
                                 else:
@@ -685,7 +685,7 @@ class NmrDataSet:
                         nd2.proc = pc
 
 
-                    elif kk is 'display':
+                    elif kk == 'display':
                         if hasattr(n, kk):
                             d = n.display
                             dp = nd2.display
@@ -697,7 +697,7 @@ class NmrDataSet:
                             nd2.display = dp
 
 
-                    elif kk is 'apc':
+                    elif kk == 'apc':
                         if hasattr(n, kk):
                             ab = n.apc
                             ac = nd2.apc
